@@ -1,11 +1,12 @@
+import warnings
 from collections import defaultdict
-from typing import Optional, List, Tuple, Union
-from mp_api.client.core import BaseRester
-from mp_api.client.core.utils import validate_ids
+from typing import List, Optional, Tuple, Union
+
 from emmet.core.thermo import ThermoDoc
 from pymatgen.analysis.phase_diagram import PhaseDiagram
 
-import warnings
+from mp_api.client.core import BaseRester
+from mp_api.client.core.utils import validate_ids
 
 
 class ThermoRester(BaseRester[ThermoDoc]):
@@ -95,6 +96,8 @@ class ThermoRester(BaseRester[ThermoDoc]):
             query_params.update({"material_ids": ",".join(validate_ids(material_ids))})
 
         if num_elements:
+            if isinstance(num_elements, int):
+                num_elements = (num_elements, num_elements)
             query_params.update(
                 {"nelements_min": num_elements[0], "nelements_max": num_elements[1]}
             )
